@@ -17,9 +17,7 @@
 #[cfg(feature = "algorithms")]
 pub use snarkvm_algorithms::{
     commitment::*,
-    commitment_tree::*,
     crh::*,
-    encoding::*,
     encryption::*,
     fft::*,
     merkle_tree::*,
@@ -32,14 +30,23 @@ pub use snarkvm_algorithms::{
 #[cfg(feature = "curves")]
 pub use snarkvm_curves::{bls12_377::*, bw6_761::*, edwards_bls12::*, edwards_bw6::*};
 
+#[cfg(feature = "dpc")]
+pub use snarkvm_dpc::*;
+
 #[cfg(feature = "fields")]
 pub use snarkvm_fields::*;
 
 #[cfg(feature = "gadgets")]
 pub use snarkvm_gadgets::*;
 
+#[cfg(feature = "marlin")]
+pub use snarkvm_marlin::*;
+
 #[cfg(feature = "polycommit")]
 pub use snarkvm_polycommit::*;
 
 #[cfg(feature = "r1cs")]
 pub use snarkvm_r1cs::*;
+
+#[cfg(test)]
+mod tests;
